==> archiva-cli-1.2.2-sources.jar: org/apache/maven/archiva/cli/AbstractProgressConsumer.java <==
package org.apache.maven.archiva.cli;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Date;

import org.apache.maven.archiva.configuration.ManagedRepositoryConfiguration;
import org.apache.maven.archiva.consumers.AbstractMonitoredConsumer;
import org.apache.maven.archiva.consumers.ConsumerException;
import org.apache.maven.archiva.consumers.RepositoryContentConsumer;

/**
 * AbstractProgressConsumer 
 *
 * @version $Id: AbstractProgressConsumer.java 718864 2008-11-19 06:33:35Z brett $
 */
public abstract class AbstractProgressConsumer
    extends AbstractMonitoredConsumer
    implements RepositoryContentConsumer
{
    private int count = 0;

    public void beginScan( ManagedRepositoryConfiguration repository, Date whenGathered )
        throws ConsumerException
    {
        this.count = 0;
    }

    public void processFile( String path )
        throws ConsumerException
    {
        count++;
        if ( ( count % 1000 ) == 0 )
        {
            System.out.println( "Files Processed: " + count );
        }

    }

    public void completeScan()
    {
        System.out.println( "Final Count of Artifacts processed by " + getId() + ": " + count );
    }

}

==> archiva-cli-1.3.8-sources.jar: org/apache/maven/archiva/cli/AbstractProgressConsumer.java <==
package org.apache.maven.archiva.cli;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Date;

import org.apache.maven.archiva.configuration.ManagedRepositoryConfiguration;
import org.apache.maven.archiva.consumers.AbstractMonitoredConsumer;
import org.apache.maven.archiva.consumers.ConsumerException;
import org.apache.maven.archiva.consumers.RepositoryContentConsumer;

/**
 * AbstractProgressConsumer 
 *
 * @version $Id$
 */
public abstract class AbstractProgressConsumer
    extends AbstractMonitoredConsumer
    implements RepositoryContentConsumer
{
    private int count = 0;

    public void beginScan( ManagedRepositoryConfiguration repository, Date whenGathered )
        throws ConsumerException
    {
        this.count = 0;
    }

    public void beginScan( ManagedRepositoryConfiguration repository, Date whenGathered, boolean executeOnEntireRepo )
        throws ConsumerException
    {
        beginScan( repository, whenGathered );
    }

    public void processFile( String path )
        throws ConsumerException
    {
        count++;
        if ( ( count % 1000 ) == 0 )
        {
            System.out.println( "Files Processed: " + count );
        }

    }

    public void processFile( String path, boolean executeOnEntireRepo )
        throws ConsumerException
    {
        processFile( path );
    }

    public void completeScan()
    {
        System.out.println( "Final Count of Artifacts processed by " + getId() + ": " + count );
    }

    public void completeScan( boolean executeOnEntireRepo )
    {
        completeScan();
    }

}
